import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  line,
  max
} from 'd3';
//importing the properties from the d3
const svg = select('svg'); //svg provides options to draw different shapes such as Lines, Rectangles, Circles.
// creating width and height for the svg diagram
const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => { //expliquer
  const title = 'ELECTRONIC SALES IN INDIA FROM 2000 TO 2013 ';
  
  const xValue = d => d.Year; //display dates sur x axis
  const xAxisLabel = 'Year';

  const yValue = d => d.ESales;
  const yAxisLabel = 'Electronic Sales';
  
  const margin = { top: 60, right: 40, bottom: 88, left: 150 };//mm manière que CSS
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  //container
  
  const xScale = scaleTime()
  //complete set of values
    .domain(extent(data, xValue)) //returns the minimum and maximum value in an array from the given array using natural order.
    .range([0, innerWidth]) //output bounds
    .nice(); //round values out
  
  const yScale = scaleLinear()
    .domain([0, max(data, yValue )])
    .range([innerHeight, 0])
    .nice();
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);//center g in svg
  
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(20);
  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10);
  
  const yAxisG = g.append('g').call(yAxis);
  	yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -90)
      .attr('x', -innerHeight / 3)
      .attr('fill', 'red')
      .attr('transform', `rotate(-90)`)
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    	.attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 70)
      .attr('x', innerWidth / 2)
      .attr('fill', 'red')
      .text(xAxisLabel);
  
  const lineGenerator = line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue(d))); //coordinates in pixels
  
  g.append('path')
  	.attr('class', 'line_path')
  	.attr('d', lineGenerator(data))
    console.log(lineGenerator(data))
  
  g.append('text')
      .attr('class', 'title')
      .attr('y', -10)
      .text(title);
};

csv('https://gist.githubusercontent.com/pavankalyan1507/663c1db5b51f655ee5023d51499e50d6/raw/59239420ffdc24defd8c103ce4bde7d2a8696521/sales.csv')
  .then(data => {
  	//console.log(data)
    data.forEach(d => {
    	d.ESales = +d.ESales;
      d.Year = new Date(d.Year)
    });
  console.log(data)
    render(data);
  })